## pipmake

A trivial python “build backend” that delegates to a Makefile.
This allows builds to be entirely controlled by ‘make’, but fully integrated with pip/pypi/etc.

Installation: `pip install pipmake`

Docs: https://pipmake.readthedocs.io/en/latest/
